@@ -1,4 +1,4 @@
-from ocp_resources.resource import NamespacedResource
+from ocp_resources.resource import MissingRequiredArgumentError, NamespacedResource
 
 
 class CatalogSource(NamespacedResource):
@@ -33,31 +33,24 @@ class CatalogSource(NamespacedResource):
         self.publisher = publisher
         self.update_strategy_registry_poll_interval = update_strategy_registry_poll_interval
 
-    def to_dict(self):
+    def to_dict(self) -> None:
         super().to_dict()
         if not self.yaml_file:
             if not all([self.source_type, self.image, self.display_name, self.publisher]):
-                raise ValueError(
-                    "Passing yaml_file or all parameters 'source_type', 'image',"
-                    " 'display_name' and 'publisher' is required."
-                )
-            self.res.update(
-                {
-                    "spec": {
-                        "sourceType": self.source_type,
-                        "image": self.image,
-                        "displayName": self.display_name,
-                        "publisher": self.publisher,
-                    }
+                raise MissingRequiredArgumentError(argument="'source_type', 'image', 'display_name' and 'publisher'")
+            self.res.update({
+                "spec": {
+                    "sourceType": self.source_type,
+                    "image": self.image,
+                    "displayName": self.display_name,
+                    "publisher": self.publisher,
                 }
-            )
+            })
             if self.update_strategy_registry_poll_interval:
-                self.res["spec"].update(
-                    {
-                        "updateStrategy": {
-                            "registryPoll": {
-                                "interval": self.update_strategy_registry_poll_interval,
-                            },
+                self.res["spec"].update({
+                    "updateStrategy": {
+                        "registryPoll": {
+                            "interval": self.update_strategy_registry_poll_interval,
                         },
-                    }
-                )
+                    },
+                })
