@@ -114,9 +114,9 @@ class NodeNetworkConfigurationPolicy(Resource):
         if self.node_selector:
             return list(Node.get(dyn_client=self.client, name=self.node_selector))
         if self.node_selector_labels:
-            node_labels = ",".join(
-                [f"{label_key}={label_value}" for label_key, label_value in self.node_selector_labels.items()]
-            )
+            node_labels = ",".join([
+                f"{label_key}={label_value}" for label_key, label_value in self.node_selector_labels.items()
+            ])
             return list(Node.get(dyn_client=self.client, label_selector=node_labels))
 
     def set_interface(self, interface):
@@ -129,7 +129,7 @@ class NodeNetworkConfigurationPolicy(Resource):
         self.desired_state["interfaces"] = interfaces
         self.res.setdefault("spec", {}).setdefault("desiredState", {})["interfaces"] = self.desired_state["interfaces"]
 
-    def to_dict(self):
+    def to_dict(self) -> None:
         super().to_dict()
         if not self.yaml_file:
             if self.dns_resolver or self.routes or self.iface:
@@ -302,7 +302,7 @@ class NodeNetworkConfigurationPolicy(Resource):
             return self
         except Exception as exp:
             self.logger.error(exp)
-            super().__exit__(exception_type=None, exception_value=None, traceback=None)
+            super().__exit__()
             raise
 
     def clean_up(self):
