@@ -41,18 +41,16 @@ class Secret(NamespacedResource):
         self.string_data = string_data
         self.type = type
 
-    def to_dict(self):
+    def to_dict(self) -> None:
         super().to_dict()
         if not self.yaml_file:
             if self.accesskeyid:
-                self.res.update(
-                    {
-                        "data": {
-                            "accessKeyId": self.accesskeyid,
-                            "secretKey": self.secretkey,
-                        }
+                self.res.update({
+                    "data": {
+                        "accessKeyId": self.accesskeyid,
+                        "secretKey": self.secretkey,
                     }
-                )
+                })
             if self.htpasswd:
                 self.res.update({"data": {"htpasswd": self.htpasswd}})
             if self.data_dict:
